summaryrefslogtreecommitdiff
path: root/includes
diff options
context:
space:
mode:
Diffstat (limited to 'includes')
-rw-r--r--includes/controllers/individual_ctrl.php4
-rw-r--r--includes/controllers/lifespan_ctrl.php2
-rw-r--r--includes/functions/functions_print_facts.php6
-rw-r--r--includes/media_reorder.php6
4 files changed, 9 insertions, 9 deletions
diff --git a/includes/controllers/individual_ctrl.php b/includes/controllers/individual_ctrl.php
index de44bf896e..f7fac77736 100644
--- a/includes/controllers/individual_ctrl.php
+++ b/includes/controllers/individual_ctrl.php
@@ -51,8 +51,8 @@ $nonfacts[] = "CHIL";
$nonfacts[] = "HUSB";
$nonfacts[] = "WIFE";
$nonfacts[] = "RFN";
-$nonfacts[] = "_WT_OBJS";
-$nonfacts[] = "_PGV_OBJS";
+$nonfacts[] = "_WT_OBJE_SORT";
+$nonfacts[] = "_WT_OBJE_SORT";
$nonfacts[] = "";
//$nonfamfacts[] = "NCHI"; // Turning back on NCHI display for the indi page.
diff --git a/includes/controllers/lifespan_ctrl.php b/includes/controllers/lifespan_ctrl.php
index ea98500657..55af468f7d 100644
--- a/includes/controllers/lifespan_ctrl.php
+++ b/includes/controllers/lifespan_ctrl.php
@@ -45,7 +45,7 @@ function compare_people($a, $b) {
// GEDCOM elements that will be found but should not be displayed
-$nonfacts = array("FAMS", "FAMC", "MAY", "BLOB", "OBJE", "SEX", "NAME", "SOUR", "NOTE", "BAPL", "ENDL", "SLGC", "SLGS", "_TODO", "_WT_OBJS", "CHAN", "HUSB", "WIFE", "CHIL", "BIRT", "DEAT", "BURI");// DEATH OF SIBLING: DEATH OF HALF SIBLING DEATH OF MOTHER DEATH OF FATHER DEATH OF CHILD
+$nonfacts = array("FAMS", "FAMC", "MAY", "BLOB", "OBJE", "SEX", "NAME", "SOUR", "NOTE", "BAPL", "ENDL", "SLGC", "SLGS", "_TODO", "_WT_OBJE_SORT", "CHAN", "HUSB", "WIFE", "CHIL", "BIRT", "DEAT", "BURI");// DEATH OF SIBLING: DEATH OF HALF SIBLING DEATH OF MOTHER DEATH OF FATHER DEATH OF CHILD
$nonfamfacts = array("CHAN", "HUSB", "WIFE", "CHIL");
/**
diff --git a/includes/functions/functions_print_facts.php b/includes/functions/functions_print_facts.php
index e1d6c636f3..f59840e3d3 100644
--- a/includes/functions/functions_print_facts.php
+++ b/includes/functions/functions_print_facts.php
@@ -1264,10 +1264,10 @@ function print_main_media($pid, $level=1, $related=false, $noedit=false) {
}
}
//LBox -- if exists, get a list of the sorted current objects in the indi gedcom record - (1 _WT_OBJS @xxx@ .... etc) ----------
$sort_current_objes = array();
- if ($level>0) $sort_regexp = "/".$level." _WT_OBJS @(.*)@/";
- else $sort_regexp = "/_WT_OBJS @(.*)@/";
+ if ($level>0) $sort_regexp = "/".$level." _WT_OBJE_SORT @(.*)@/";
+ else $sort_regexp = "/_WT_OBJE_SORT @(.*)@/";
$sort_ct = preg_match_all($sort_regexp, $gedrec, $sort_match, PREG_SET_ORDER);
for($i=0; $i<$sort_ct; $i++) {
if (!isset($sort_current_objes[$sort_match[$i][1]])) $sort_current_objes[$sort_match[$i][1]] = 1;
@@ -1264,10 +1264,10 @@ function print_main_media($pid, $level=1, $related=false, $noedit=false) {
}
}
- //LBox -- if exists, get a list of the sorted current objects in the indi gedcom record - (1 _WT_OBJS @xxx@ .... etc) ----------
+ //LBox -- if exists, get a list of the sorted current objects in the indi gedcom record - (1 _WT_OBJE_SORT @xxx@ .... etc) ----------
$sort_current_objes = array();
diff --git a/includes/media_reorder.php b/includes/media_reorder.php
index b6b13ca75d..5c9bbf6fde 100644
--- a/includes/media_reorder.php
+++ b/includes/media_reorder.php
@@ -81,10 +81,10 @@ require_once WT_ROOT.'includes/functions/functions_print_facts.php';
}
}
//-- If they exist, get a list of the sorted current objects in the indi gedcom record - (1 _WT_OBJS @xxx@ .... etc) ----------
$sort_current_objes = array();
- if ($level>0) $sort_regexp = "/".$level." _WT_OBJS @(.*)@/";
- else $sort_regexp = "/_WT_OBJS @(.*)@/";
+ if ($level>0) $sort_regexp = "/".$level." _WT_OBJE_SORT @(.*)@/";
+ else $sort_regexp = "/_WT_OBJE_SORT @(.*)@/";
$sort_ct = preg_match_all($sort_regexp, $gedrec, $sort_match, PREG_SET_ORDER);
for ($i=0; $i<$sort_ct; $i++) {
if (!isset($sort_current_objes[$sort_match[$i][1]])) $sort_current_objes[$sort_match[$i][1]] = 1;
@@ -81,10 +81,10 @@ require_once WT_ROOT.'includes/functions/functions_print_facts.php';
}
}
- //-- If they exist, get a list of the sorted current objects in the indi gedcom record - (1 _WT_OBJS @xxx@ .... etc) ----------
+ //-- If they exist, get a list of the sorted current objects in the indi gedcom record - (1 _WT_OBJE_SORT @xxx@ .... etc) ----------
$sort_current_objes = array();